@@ -3,6 +3,7 @@ Log <- function(expression, inst = NULL){
          term = function(predLabels, ...) {
              paste("log(", predLabels, ")", sep = "")
          },
-         call = as.expression(match.call()))
+         call = as.expression(match.call()),
+         match = 1)
 }
 class(Log) <- "nonlin"
